<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>FontsDialog</name>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="28"/>
        <source>LabelsFont</source>
        <translation>Libelés</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="31"/>
        <location filename="../../src/FontsDialog.cpp" line="51"/>
        <source>ResetDefaultValue</source>
        <translation>Valeur orig.</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="48"/>
        <source>FieldsFont</source>
        <translation>Champs</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="63"/>
        <source>LanguageFontOverrides</source>
        <translation>Surdéfinitions par langue</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="73"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="75"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../src/FontsDialog.cpp" line="89"/>
        <source>Fonts Settings</source>
        <translation>Polices de caractères</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="8"/>
        <source>Home</source>
        <translation>Maison</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="9"/>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../../src/HelpBrowser.cpp" line="30"/>
        <source>Help: %1</source>
        <translation>Aide: %1</translation>
    </message>
</context>
<context>
    <name>KeyboardAcceleratorsDialog</name>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="23"/>
        <source>Key</source>
        <translation>Touche</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="43"/>
        <source>Clear key</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="44"/>
        <source>Set key</source>
        <translation>Définir</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="45"/>
        <source>Reset key</source>
        <translation>Valeur orig.</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="63"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="87"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Raccourcis-Clavier</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="122"/>
        <source>&lt;press key&gt;</source>
        <translation>&lt;Tapez raccourci&gt;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="190"/>
        <source>Duplicate key binding</source>
        <translation>Raccourci doublon</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>Key &apos;</source>
        <translation>Le raccourci &apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="191"/>
        <source>&apos;
is currently assigned to
&apos;</source>
        <translation>&apos;
est déjà assigné à
&apos;</translation>
    </message>
    <message>
        <location filename="../../src/KeyboardAcceleratorsDialog.cpp" line="192"/>
        <source>&apos;.
Overwrite the current assignment?</source>
        <translation>&apos;.
Affecter le raccourci quand même?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/MainWindow.cpp" line="60"/>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <location filename="../../src/MainWindow.cpp" line="217"/>
        <source>StartQuiz</source>
        <translation>Débuter le quiz</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="62"/>
        <location filename="../../src/MainWindow.cpp" line="218"/>
        <source>ManageGlossaries</source>
        <translation>Administrer les glossaires</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="64"/>
        <location filename="../../src/MainWindow.cpp" line="219"/>
        <source>Import...</source>
        <translation>Importer Données</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="66"/>
        <location filename="../../src/MainWindow.cpp" line="220"/>
        <source>Export...</source>
        <translation>Exporter Données</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="70"/>
        <location filename="../../src/MainWindow.cpp" line="222"/>
        <source>Preferences...</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="72"/>
        <location filename="../../src/MainWindow.cpp" line="223"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="132"/>
        <location filename="../../src/MainWindow.cpp" line="236"/>
        <source>About...</source>
        <translation>À Propos de toMOTko</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="176"/>
        <source>RestartQuiz</source>
        <translation>Recommencer le quiz</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="68"/>
        <location filename="../../src/MainWindow.cpp" line="221"/>
        <source>ShowAllGlossariesAndTerms</source>
        <translation>Voir tous les glossaires/mots</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutToMOTko...</source>
        <translation>À propos de toMOTko...</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="275"/>
        <source>AboutMessage</source>
        <translation>&lt;html&gt;&lt;h2&gt;toMOTko v0.11.2&lt;/h2&gt;&lt;p&gt;Petite application facilitant l&apos;apprentissage de vocabulaire.&lt;/p&gt;&lt;p&gt;Écrit par Frédéric Bergeron&lt;br/&gt;(&lt;a href=&quot;mailto:fbergeron@users.sourceforge.net&quot;&gt;fbergeron@users.sourceforge.net&lt;/a&gt;)&lt;br/&gt;Copyright (c) 2006-2010&lt;/p&gt;&lt;p&gt;Ce programme est GPL v2.&lt;/p&gt;&lt;p&gt;Site web: &lt;a href=&quot;http://tomotko.sourceforge.net&quot;&gt;http://tomotko.sourceforge.net&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="52"/>
        <location filename="../../src/MainWindow.cpp" line="213"/>
        <source>Reveal</source>
        <translation>Dévoiler</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="54"/>
        <location filename="../../src/MainWindow.cpp" line="214"/>
        <source>RightAnswer</source>
        <translation>Bonne réponse</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="56"/>
        <location filename="../../src/MainWindow.cpp" line="215"/>
        <source>WrongAnswer</source>
        <translation>Mauvaise réponse</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="58"/>
        <location filename="../../src/MainWindow.cpp" line="216"/>
        <source>EditQuizTerm</source>
        <translation>Éditer un mot du quiz</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="74"/>
        <location filename="../../src/MainWindow.cpp" line="224"/>
        <source>AddFolder</source>
        <translation>Ajouter dossier</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="76"/>
        <location filename="../../src/MainWindow.cpp" line="225"/>
        <source>AddGlossary</source>
        <translation>Ajouter glossaire</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="78"/>
        <location filename="../../src/MainWindow.cpp" line="226"/>
        <source>RemoveItem</source>
        <translation>Effacer l&apos;item</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="80"/>
        <location filename="../../src/MainWindow.cpp" line="227"/>
        <source>AddTerm</source>
        <translation>Ajouter un mot</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="82"/>
        <location filename="../../src/MainWindow.cpp" line="228"/>
        <source>EditTerm</source>
        <translation>Éditer un mot</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="84"/>
        <location filename="../../src/MainWindow.cpp" line="229"/>
        <source>RemoveTerm</source>
        <translation>Effacer un ou des mots</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="86"/>
        <location filename="../../src/MainWindow.cpp" line="230"/>
        <source>CheckAllTerms</source>
        <translation>Cocher tous les mots</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="88"/>
        <location filename="../../src/MainWindow.cpp" line="231"/>
        <source>InverseCheckedTerms</source>
        <translation>Inverser la sélection des mots cochés</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="90"/>
        <location filename="../../src/MainWindow.cpp" line="232"/>
        <source>Maximize</source>
        <translation>Agrandir</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <source>ConfirmResumeQuiz</source>
        <translation>Il y a déjà un quiz en cours pour les langues sélectionnées. Voulez-vous continuer ce quiz?</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="304"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="305"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <source>NoTermsMarkedForStudy</source>
        <translation>Le quiz ne peut débuter car vous n&apos;avez spécifié aucun mot à étudier.  Utilisez le gestionnaire de glossaires et cochez les mots désirés.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <source>TermsMissing</source>
        <translation>Les mots du quiz sont introuvables. Impossible d&apos;amorcer le quiz.</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="92"/>
        <location filename="../../src/MainWindow.cpp" line="233"/>
        <source>Search...</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="130"/>
        <location filename="../../src/MainWindow.cpp" line="235"/>
        <source>Help...</source>
        <translation>Aide</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="73"/>
        <source>DigraphesEnabled</source>
        <translation>Digraphes activés</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="34"/>
        <source>Length</source>
        <translation>Longueur des
quizzes (répétitions)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="54"/>
        <source>QuizLengthShortest</source>
        <translation>Court (1)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="55"/>
        <source>QuizLengthMedium</source>
        <translation>Moyen (3)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="57"/>
        <source>QuizLengthLongest</source>
        <translation>Long (5)</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="87"/>
        <source>InterfaceLanguage</source>
        <translation>Langue d&apos;interface</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="143"/>
        <source>Revealing Sequences Settings</source>
        <translation>Dévoilement...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="189"/>
        <source>Preferences...</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="134"/>
        <source>Keyboard Accelerator Definitions</source>
        <translation>Raccourcis-Clavier...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="76"/>
        <source>hideQuizButtons</source>
        <translation>Cacher Boutons du Quiz</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="79"/>
        <source>ShowAltInTermList</source>
        <translation>Afficher Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="137"/>
        <source>Study Language Definitions</source>
        <translation>Langues d&apos;intérêt...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="140"/>
        <source>Fonts Settings</source>
        <translation>Polices de caractères...</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="151"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/PreferencesDialog.cpp" line="153"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PropertiesPanel</name>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="59"/>
        <location filename="../../src/PropertiesPanel.cpp" line="92"/>
        <source>Words</source>
        <translation>Mots</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="99"/>
        <source>Glossaries</source>
        <translation>Glossaires</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="106"/>
        <source>Folders</source>
        <translation>Dossiers</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="127"/>
        <location filename="../../src/PropertiesPanel.cpp" line="284"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="133"/>
        <location filename="../../src/PropertiesPanel.cpp" line="279"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="137"/>
        <location filename="../../src/PropertiesPanel.cpp" line="280"/>
        <source>Content</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Items</source>
        <translation>Items</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Selected</source>
        <translation>Quiz</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Checked</source>
        <translation>Cochés</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="144"/>
        <location filename="../../src/PropertiesPanel.cpp" line="282"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="169"/>
        <location filename="../../src/PropertiesPanel.cpp" line="285"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="175"/>
        <location filename="../../src/PropertiesPanel.cpp" line="286"/>
        <source>CreationDate</source>
        <translation>Création</translation>
    </message>
    <message>
        <location filename="../../src/PropertiesPanel.cpp" line="181"/>
        <location filename="../../src/PropertiesPanel.cpp" line="287"/>
        <source>ModificationDate</source>
        <translation>Modification</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>ar</source>
        <translation>Arabe</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>bg</source>
        <translation>Bulgare</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>el</source>
        <translation>Grec</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>cs</source>
        <translation>Tchèque</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="5"/>
        <source>da</source>
        <translation>Danois</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>it</source>
        <translation>Italien</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>eo</source>
        <translation>Espéranto</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>fi</source>
        <translation>Finnois</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>he</source>
        <translation>Hébreu</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hi</source>
        <translation>Hindî</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="6"/>
        <source>hu</source>
        <translation>Hongrois</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>ko</source>
        <translation>Koréen</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>nl</source>
        <translation>Néerlandais</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>pt</source>
        <translation>Portuguais</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>la</source>
        <translation>Latin</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>no</source>
        <translation>Norvégien</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="7"/>
        <source>rm</source>
        <translation>Romanche</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ru</source>
        <translation>Russe</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sw</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>th</source>
        <translation>Thaï</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>ro</source>
        <translation>Roumain</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="8"/>
        <source>sv</source>
        <translation>Suédois</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>vi</source>
        <translation>Vietnamien</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>zh</source>
        <translation>Chinois</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="9"/>
        <source>tl</source>
        <translation>Tagalog</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>en</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>fr</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>es</source>
        <translation>Espagnol</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>ja</source>
        <translation>Japonais</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="4"/>
        <source>de</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="40"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="39"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="41"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="../../src/ResultListItem.cpp" line="20"/>
        <location filename="../../src/ResultListItem.cpp" line="33"/>
        <location filename="../../src/TermListItem.cpp" line="23"/>
        <location filename="../../src/TermListItem.cpp" line="36"/>
        <source>Undefined</source>
        <translation>Non défini</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="46"/>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <location filename="../../src/VocabParser.cpp" line="85"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="270"/>
        <source>ErrorSavingData</source>
        <translation>Un problème est survenu durant la sauvegarde des données. Vérifiez l&apos;espace-disque et les droits d&apos;accès aux fichiers.</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <location filename="../../src/MainWindow.cpp" line="298"/>
        <location filename="../../src/MainWindow.cpp" line="317"/>
        <location filename="../../src/MainWindow.cpp" line="322"/>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="408"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>OperationSuccessful</source>
        <translation>Opération réussie</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>OperationFailed</source>
        <translation>Opération échouée</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="737"/>
        <source>MyGlossaries</source>
        <translation>Mes glossaires</translation>
    </message>
    <message>
        <location filename="../../src/FolderParser.cpp" line="47"/>
        <location filename="../../src/VocabParser.cpp" line="86"/>
        <source>ParseError</source>
        <translation>Erreur de parsing à la
ligne %1, colonne %2.
%3.</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="144"/>
        <source>NewFolder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <location filename="../../src/Controller.cpp" line="173"/>
        <source>NewGlossary</source>
        <translation>Nouveau glossaire</translation>
    </message>
</context>
<context>
    <name>QuizFrame</name>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="104"/>
        <location filename="../../src/QuizFrame.cpp" line="139"/>
        <location filename="../../src/QuizFrame.cpp" line="149"/>
        <location filename="../../src/QuizFrame.cpp" line="187"/>
        <location filename="../../src/QuizFrame.cpp" line="202"/>
        <location filename="../../src/QuizFrame.cpp" line="636"/>
        <location filename="../../src/QuizFrame.cpp" line="639"/>
        <location filename="../../src/QuizFrame.cpp" line="640"/>
        <location filename="../../src/QuizFrame.cpp" line="643"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="387"/>
        <source>WellDone</source>
        <translation>Félicitations! Vous avez appris tous les %1 mots sélectionnés.  Utilisez le gestionnaire de glossaires pour en étudier d&apos;autres.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="757"/>
        <location filename="../../src/QuizFrame.cpp" line="763"/>
        <source>DissociatedWord</source>
        <translation>Le mot a été dissocié de son glossaire original.  L&apos;édition est impossible via le quiz.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="99"/>
        <location filename="../../src/QuizFrame.cpp" line="128"/>
        <location filename="../../src/QuizFrame.cpp" line="635"/>
        <location filename="../../src/QuizFrame.cpp" line="638"/>
        <source>Word/Expr.</source>
        <translation>Mot/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="126"/>
        <location filename="../../src/QuizFrame.cpp" line="637"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="169"/>
        <location filename="../../src/QuizFrame.cpp" line="642"/>
        <source>Examples/Comments</source>
        <translation>Exemples/Commentaires</translation>
    </message>
    <message>
        <location filename="../../src/QuizFrame.cpp" line="197"/>
        <location filename="../../src/QuizFrame.cpp" line="641"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="47"/>
        <location filename="../../src/SearchDialog.cpp" line="169"/>
        <source>Results</source>
        <translation>Résultats</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Glossary</source>
        <translation>Glossaire</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="61"/>
        <location filename="../../src/SearchDialog.cpp" line="174"/>
        <source>Location</source>
        <translation>Chemin</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="72"/>
        <location filename="../../src/SearchDialog.cpp" line="176"/>
        <source>View Glossary</source>
        <translation>Voir le glossaire</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="113"/>
        <location filename="../../src/SearchDialog.cpp" line="187"/>
        <source>Search...</source>
        <translation>Rechercher...</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="77"/>
        <location filename="../../src/SearchDialog.cpp" line="178"/>
        <source>Edit Term</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="82"/>
        <location filename="../../src/SearchDialog.cpp" line="180"/>
        <source>Remove Term(s)</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="88"/>
        <location filename="../../src/SearchDialog.cpp" line="182"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="170"/>
        <location filename="../../src/SearchDialog.cpp" line="208"/>
        <source>%1 term(s) found</source>
        <translation>%1 mot(s) trouvé(s)</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="288"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Êtes-vous certain de vouloir effacer le(s) mot(s) sélectionné(s)?</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="294"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="295"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Suppression de mots</translation>
    </message>
    <message>
        <location filename="../../src/SearchDialog.cpp" line="336"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Certains des mots sélectionnés contiennent des traductions dans plusieurs langues.  Indiquez les traductions à effacer.</translation>
    </message>
</context>
<context>
    <name>SequenceDialog</name>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="22"/>
        <source>Quiz</source>
        <translation>Fenêtre de quiz</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="52"/>
        <source>FirstLanguage</source>
        <translation>Langue source</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="56"/>
        <location filename="../../src/SequenceDialog.cpp" line="88"/>
        <source>Word/Expr.</source>
        <translation>Mot/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="72"/>
        <source>TestLanguage</source>
        <translation>Langue cible</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="86"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="102"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="115"/>
        <source>CommentLabelPanel</source>
        <translation>Examples/Commentaires</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="128"/>
        <source>Sequence</source>
        <translation>Séquence</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="191"/>
        <source>AddRevealingSequence</source>
        <translation>Ajouter une séquence de dévoilement...</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="200"/>
        <source>SequenceIsEmpty</source>
        <translation>La séquence en courѕ d&apos;édition est vide.  Pour annuler l&apos;opération, cliquez sur Annuler pour fermer la fenêtre de dialogue.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="206"/>
        <source>SequenceNotTerminated</source>
        <translation>La séquence en cours d&apos;édition est invalide car elle ne se termine pas par un item dévoilable.  Veuillez ajouter un item dévoible ou effacer le dernier opérateur d&apos;union.</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="166"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequenceDialog.cpp" line="168"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>SequencesDialog</name>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="23"/>
        <source>Existing Sequences</source>
        <translation>Séquences existantes</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="47"/>
        <source>QuizWindow</source>
        <translation>Fenêtre de Quiz</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="62"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="78"/>
        <source>RevealingOrders</source>
        <translation>Séquences de dévoilement</translation>
    </message>
    <message>
        <location filename="../../src/SequencesDialog.cpp" line="85"/>
        <source>RevealingOrderMandatory</source>
        <translation>Vous devez choisir au moins une séquence de dévoilement.  Créez-en une nouvelle au besoin.</translation>
    </message>
</context>
<context>
    <name>StudyLanguagesDialog</name>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="26"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="45"/>
        <source>Study Language Definitions</source>
        <translation>Langues d&apos;intérêt</translation>
    </message>
    <message>
        <location filename="../../src/StudyLanguagesDialog.cpp" line="87"/>
        <source>StudyLanguagesMandatory</source>
        <translation>Vous devez sélectionner au moins deux langues d&apos;intérêt
(une langue source et une langue cible.)</translation>
    </message>
</context>
<context>
    <name>TermDialog</name>
    <message>
        <location filename="../../src/TermDialog.cpp" line="62"/>
        <location filename="../../src/TermDialog.cpp" line="84"/>
        <source>Word/Expr.</source>
        <translation>Mot/Expr.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="82"/>
        <source>Alt./Phon.</source>
        <translation>Alt./Phon.</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="109"/>
        <source>Examples/Comments</source>
        <translation>Exemples/Commentaires</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="167"/>
        <source>EditTerm</source>
        <translation>Édition d&apos;un mot</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="137"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="128"/>
        <source>setImage</source>
        <translation>Choisir</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="132"/>
        <source>clearImage</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>SetImage...</source>
        <translation>Choisir...</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="148"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="150"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="214"/>
        <source>Images (*.png *.gif)</source>
        <translation>Images (*.png *.gif)</translation>
    </message>
    <message>
        <location filename="../../src/TermDialog.cpp" line="246"/>
        <source>CannotReadImage</source>
        <translation>Impossible de lire l&apos;image sélectionnée.</translation>
    </message>
</context>
<context>
    <name>TranslationSelectionDialog</name>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="15"/>
        <source>Languages</source>
        <translation>Langues</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="37"/>
        <source>CheckAllLanguages</source>
        <translation>Cocher toutes les langues</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="45"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../src/TranslationSelectionDialog.cpp" line="47"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>Util</name>
    <message>
        <location filename="../../src/Util.cpp" line="22"/>
        <source>VerySmall</source>
        <translation>Très petit</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="23"/>
        <source>Small</source>
        <translation>Petit</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="24"/>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="25"/>
        <source>Large</source>
        <translation>Grand</translation>
    </message>
    <message>
        <location filename="../../src/Util.cpp" line="26"/>
        <source>VeryLarge</source>
        <translation>Très grand</translation>
    </message>
</context>
<context>
    <name>VocabularyManagerFrame</name>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTermsCaption</source>
        <translation>Suppression de mots</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="1015"/>
        <source>MultipleTranslationsDetectedForRemoveTerms</source>
        <translation>Certains des mots sélectionnés contiennent des traductions dans plusieurs langues.  Indiquez les traductions à effacer.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>MultipleTranslationsDetectedForImport</source>
        <translation>Le fichier contient des mots traduits dans plusieurs langues.  Veuillez indiquer les traductions à importer.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <source>MultipleTranslationsDetectedForExport</source>
        <translation>Le glossaire contient des mots traduits dans plusieurs langues.  Veuillez indiquer les traductions à exporter.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="839"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="973"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="840"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="974"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="46"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="596"/>
        <source>Glossaries</source>
        <translation>Glossaires</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="458"/>
        <source>GlossaryExportSuccessful</source>
        <translation>Le glossaire a été exporté avec succès.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="416"/>
        <source>ItemImportFailed</source>
        <translation>Une erreur est survenue. Les données n&apos;ont pas pu être importées.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="419"/>
        <source>ItemImportFailedZipFileExpected</source>
        <translation>Format de fichier invalide. Un fichier .zip était attendu. Les données n&apos;ont pas pu être importées.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="460"/>
        <source>GlossaryExportFailed</source>
        <translation>Une erreur est survenue. Le glossaire n&apos;a pas pu être exporté.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="833"/>
        <source>ConfirmRemoveItem</source>
        <translation>Êtes-vous certain de vouloir effacer cet item?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="967"/>
        <source>ConfirmRemoveSelectedTerms</source>
        <translation>Êtes-vous certain de vouloir effacer le(s) mot(s) sélectionné(s)?</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="186"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="604"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="187"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="605"/>
        <source>Words</source>
        <translation>Mots</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <source>MultipleTranslationsDetectedForFolderExport</source>
        <translation>Le dossier contient des mots traduits dans plusieurs langues.  Veuillez indiquer les traductions à exporter.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="484"/>
        <source>FolderExportSuccessful</source>
        <translation>Le dossier a été exporté avec succès.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="486"/>
        <source>FolderExportFailed</source>
        <translation>Une erreur est survenue. Le dossier n&apos;a pas pu être exporté.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="361"/>
        <source>Import...</source>
        <translation>Importer...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="405"/>
        <source>ImportSuccessful</source>
        <translation>Les données ont été importées avec succès.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="407"/>
        <source>InvisibleImport</source>
        <translation>

Les données importées ne sont pas visibles pour le moment.  Pour les voir, vous devez sélectionner les langues appropriées dans les sélecteurs de langues.</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="442"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="453"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="468"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="479"/>
        <source>Export...</source>
        <translation>Exporter...</translation>
    </message>
    <message>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="353"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="454"/>
        <location filename="../../src/VocabularyManagerFrame.cpp" line="480"/>
        <source>Glossaries (*.zip)</source>
        <translation>Glossaires (*.zip)</translation>
    </message>
</context>
</TS>
